=======================
The ``synodal`` package
=======================

This currently consists of a single Python script `synodal.py`, which does
nothing but contain information about the SynodalSoft project.


Source code repository: https://gitlab.com/lino-framework/synodal
